import { Box, Input, Button, FormControl, FormLabel, useToast } from '@chakra-ui/react';
import { useState } from 'react';

type NewsletterSignupProps = {
  onClose: () => void;
};

export default function NewsletterSignup({ onClose }: NewsletterSignupProps) {
  const [email, setEmail] = useState('');
  const toast = useToast();

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    // Pretend to subscribe
    toast({
      title: 'Subscribed!',
      description: `You have subscribed with ${email}`,
      status: 'success',
      duration: 3000,
      isClosable: true,
    });
    setEmail('');
    onClose();  // Close the modal here
  };

  return (
    <Box as="form" onSubmit={handleSubmit}>
      <FormControl id="email" isRequired>
        <FormLabel>Email address</FormLabel>
        <Input
          type="email"
          value={email}
          placeholder="Enter your email"
          onChange={(e) => setEmail(e.target.value)}
        />
      </FormControl>
      <Button mt={4} type="submit" colorScheme="teal" w="full">
        Subscribe
      </Button>
    </Box>
  );
}
